@@ -4,9 +4,8 @@ from collections import Iterator
 import numpy as np
 import pandas as pd
 from datashape.dispatch import dispatch
-from datashape import from_numpy
+from datashape import from_numpy, var
 
-import dask
 from dask.array.core import Array, from_array
 from dask.bag.core import Bag
 import dask.bag as db
@@ -22,6 +21,12 @@ def discover_dask_array(a, **kwargs):
     return from_numpy(a.shape, a.dtype)
 
 
+@discover.register(dd.Series)
+@discover.register(dd.DataFrame)
+def discover_dask_dataframe(df):
+    return var * discover(df.head()).measure
+
+
 arrays = [np.ndarray]
 
 try:
@@ -66,10 +71,10 @@ def dask_to_numpy(x, **kwargs):
     return np.array(x)
 
 
-@convert.register(pd.DataFrame, dd.DataFrame, cost=10)
-@convert.register(pd.Series, dd.Series, cost=10)
-@convert.register(float, Array, cost=10.)
-def dask_to_float(x, **kwargs):
+@convert.register(pd.DataFrame, dd.DataFrame, cost=200)
+@convert.register(pd.Series, dd.Series, cost=200)
+@convert.register(float, Array, cost=200)
+def dask_to_other(x, **kwargs):
     return x.compute()
 
 
