@@ -9,7 +9,7 @@ import decimal
 from operator import attrgetter
 from itertools import chain
 from collections import Iterator
-from datetime import datetime, date
+from datetime import datetime, date, timedelta
 from distutils.spawn import find_executable
 
 import pandas as pd
@@ -28,8 +28,8 @@ from datashape import discover, datetime_, date_, float64, int64, int_, string
 from datashape import float32
 from datashape.dispatch import dispatch
 
-from toolz import (partition_all, keyfilter, memoize, valfilter, identity,
-                   concat, curry, merge)
+from toolz import (partition_all, keyfilter, valfilter, identity, concat,
+                   curry, merge, memoize)
 from toolz.curried import pluck, map
 
 from ..compatibility import unicode
@@ -40,7 +40,7 @@ from ..resource import resource
 from ..chunks import Chunks
 from .csv import CSV
 
-base = int, float, datetime, date, bool, str, decimal.Decimal
+base = int, float, datetime, date, bool, str, decimal.Decimal, timedelta
 
 
 # http://docs.sqlalchemy.org/en/latest/core/types.html
@@ -109,7 +109,7 @@ def getbind(t, bind):
 
     if isinstance(bind, sa.engine.base.Engine):
         return bind
-    return sa.create_engine(bind)
+    return create_engine(bind)
 
 
 def batch(sel, chunksize=10000, bind=None):
@@ -213,19 +213,39 @@ def metadata_of_engine(engine, schema=None):
     return sa.MetaData(engine, schema=schema)
 
 
-def create_engine(uri, *args, **kwargs):
-    if ':memory:' in uri:
-        return sa.create_engine(uri, *args, **kwargs)
-    else:
-        return memoized_create_engine(uri, *args, **kwargs)
+def create_engine(uri, connect_args=None, **kwargs):
+    """Creates a cached sqlalchemy engine.
+
+    This differs from ``sa.create_engine``\s api by only accepting
+    ``uri`` positionally.
+
+    If the ``uri`` is an in memory sqlite database then this will not memioize
+    the engine.
+    """
+    return (
+        _create_engine_hashable_args
+        if uri == 'sqlite:///:memory:' else
+        _memoized_create_engine_hashable_args
+    )(uri, connect_args=frozenset((connect_args or {}).items()), **kwargs)
 
 
-memoized_create_engine = memoize(sa.create_engine)
+def _create_engine_hashable_args(uri, connect_args=None, **kwargs):
+    """Unpacks non-hashable args for ``sa.create_engine`` and puts that back
+    into whatever structure is expected.
+    """
+    return sa.create_engine(
+        uri,
+        connect_args=dict(connect_args or {}),
+        **kwargs
+    )
+
+
+_memoized_create_engine_hashable_args = memoize(_create_engine_hashable_args)
 
 
 @dispatch(sa.engine.base.Engine, str)
 def discover(engine, tablename):
-    metadata = metadata_of_engine(engine)
+    metadata = sa.MetaData(engine)
     if tablename not in metadata.tables:
         try:
             metadata.reflect(engine,
@@ -238,8 +258,7 @@ def discover(engine, tablename):
 
 @dispatch(sa.engine.base.Engine)
 def discover(engine):
-    metadata = metadata_of_engine(engine)
-    return discover(metadata)
+    return discover(metadata_of_engine(engine))
 
 
 @dispatch(sa.MetaData)
@@ -400,7 +419,7 @@ def select_to_iterator(sel, dshape=None, bind=None, **kwargs):
     return func(rows)
 
 
-@convert.register(base, sa.sql.Select, cost=300.0)
+@convert.register(base, sa.sql.Select, cost=200.0)
 def select_to_base(sel, dshape=None, bind=None, **kwargs):
     if dshape is not None and not isscalar(dshape):
         raise ValueError('dshape should be None or scalar, got %s' % dshape)
@@ -421,7 +440,7 @@ def append_iterator_to_table(t, rows, dshape=None, bind=None, **kwargs):
     try:
         row = next(rows)
     except StopIteration:
-        return
+        return t
     rows = chain([row], rows)
     if isinstance(row, (tuple, list)):
         dshape = dshape and datashape.dshape(dshape)
@@ -506,7 +525,12 @@ def attach_schema(obj, schema):
 
 @resource.register(r'(.*sql.*|oracle|redshift)(\+\w+)?://.+')
 def resource_sql(uri, *args, **kwargs):
-    engine = create_engine(uri, **filter_kwargs(sa.create_engine, kwargs))
+    engine = create_engine(
+        uri,
+        # roundtrip through a frozenset of tuples so we can cache the dict
+        connect_args=kwargs.pop('connect_args', {}),
+        **filter_kwargs(sa.create_engine, kwargs)
+    )
     ds = kwargs.pop('dshape', None)
     schema = kwargs.pop('schema', None)
     foreign_keys = kwargs.pop('foreign_keys', None)
@@ -519,9 +543,12 @@ def resource_sql(uri, *args, **kwargs):
 
         with ignoring(sa.exc.NoSuchTableError):
             return attach_schema(
-                sa.Table(table_name, metadata, schema=schema,
-                         autoload_with=engine),
-                schema
+                sa.Table(
+                    table_name,
+                    metadata,
+                    autoload_with=engine,
+                ),
+                schema,
             )
         if ds:
             t = dshape_to_table(table_name, ds, metadata=metadata,
@@ -593,6 +620,7 @@ def drop(table, bind=None):
     table.drop(bind=bind, checkfirst=True)
     if table.exists(bind=bind):
         raise ValueError('table %r dropped but still exists' % table.name)
+    metadata_of_engine(bind, schema=table.schema).remove(table)
 
 
 @convert.register(pd.DataFrame, (sa.sql.Select, sa.sql.Selectable), cost=200.0)
