@@ -5,20 +5,19 @@ pytest.importorskip('sqlalchemy')
 
 import os
 from decimal import Decimal
+from functools import partial
 
+import datashape
+from datashape import discover, dshape, float32, float64
 import numpy as np
 import pandas as pd
-
 import sqlalchemy as sa
 
-from datashape import discover, dshape, float32, float64
-import datashape
-
+from odo import convert, append, resource, into, odo, chunks
 from odo.backends.sql import (
     dshape_to_table, create_from_datashape, dshape_to_alchemy
 )
 from odo.utils import tmpfile, raises
-from odo import convert, append, resource, discover, into, odo, chunks
 
 
 def test_resource():
@@ -336,11 +335,11 @@ def test_append_from_select(sqlite_file):
     raw = np.array([(200.0, 'Glenn'),
                     (314.14, 'Hope'),
                     (235.43, 'Bob')], dtype=[('amount', 'float64'),
-                                             ('name', 'S5')])
+                                             ('name', 'U5')])
     raw2 = np.array([(800.0, 'Joe'),
                      (914.14, 'Alice'),
                      (1235.43, 'Ratso')], dtype=[('amount', 'float64'),
-                                                 ('name', 'S5')])
+                                                 ('name', 'U5')])
     t = into('%s::t' % sqlite_file, raw)
     s = into('%s::s' % sqlite_file, raw2)
     t = append(t, s.select())
@@ -356,11 +355,11 @@ def test_append_from_table():
         raw = np.array([(200.0, 'Glenn'),
                         (314.14, 'Hope'),
                         (235.43, 'Bob')], dtype=[('amount', 'float64'),
-                                                 ('name', 'S5')])
+                                                 ('name', 'U5')])
         raw2 = np.array([(800.0, 'Joe'),
                          (914.14, 'Alice'),
                          (1235.43, 'Ratso')], dtype=[('amount', 'float64'),
-                                                     ('name', 'S5')])
+                                                     ('name', 'U5')])
         t = into('sqlite:///%s::t' % fn, raw)
         s = into('sqlite:///%s::s' % fn, raw2)
         t = append(t, s)
@@ -733,3 +732,28 @@ def test_decimal_conversion():
         t = odo(data, 'sqlite:///%s::x' % fn, dshape='var * {x: decimal[11, 2]}')
         result = odo(sa.select([sa.func.sum(t.c.x)]), Decimal)
     assert result == sum(Decimal(r[0]) for r in data)
+
+
+def test_append_empty_iterator_returns_table():
+    with tmpfile('.db') as fn:
+        t = resource('sqlite:///%s::x' % fn, dshape='var * {a: int32}')
+        assert odo(iter([]), t) is t
+
+
+def test_pass_non_hashable_arg_to_create_engine():
+    with tmpfile('.db') as fn:
+        r = partial(
+            resource,
+            'sqlite:///%s::t' % fn,
+            connect_args={},
+            dshape='var * {a: int32}',
+        )
+        assert r() is r()
+
+    s = partial(
+        resource,
+        'sqlite:///:memory:::t',
+        connect_args={},
+        dshape='var * {a: int32}',
+    )
+    assert s() is not s()
