@@ -1,5 +1,7 @@
 from __future__ import absolute_import, division, print_function
 
+import warnings
+import functools
 import inspect
 import datetime
 import tempfile
@@ -94,9 +96,9 @@ def expand_tuples(L):
 
 
 @contextmanager
-def tmpfile(extension=''):
+def tmpfile(extension='', dir=None):
     extension = '.' + extension.lstrip('.')
-    handle, filename = tempfile.mkstemp(extension)
+    handle, filename = tempfile.mkstemp(extension, dir=dir)
     os.close(handle)
     os.remove(filename)
 
@@ -389,7 +391,7 @@ def filter_kwargs(f, kwargs):
 def copydoc(from_, to):
     """Copies the docstring from one function to another.
 
-    Paramaters
+    Parameters
     ----------
     from_ : any
         The object to copy the docstring from.
@@ -403,3 +405,23 @@ def copydoc(from_, to):
     """
     to.__doc__ = from_.__doc__
     return to
+
+def deprecated(replacement=None):
+    """A decorator which can be used to mark functions as deprecated.
+    replacement is a callable that will be called with the same args
+    as the decorated function.
+    """
+    def outer(fun):
+        msg = "{} is deprecated".format(fun.__name__)
+        if replacement is not None:
+            msg += "; use {} instead".format(replacement)
+        if fun.__doc__ is None:
+            fun.__doc__ = msg
+    
+        @functools.wraps(fun)
+        def inner(*args, **kwargs):
+            warnings.warn(msg, category=DeprecationWarning, stacklevel=2)
+            return fun(*args, **kwargs)
+    
+        return inner
+    return outer
